@@ -45,10 +45,10 @@ impl Boolean {
     pub fn to_condition(
         &self,
         line_number: usize,
-        all_locals: &mut ftd_rt::Map,
+        all_locals: &mut ftd::Map,
         arguments: &std::collections::BTreeMap<String, crate::Value>,
         doc_id: &str,
-    ) -> ftd::p1::Result<ftd_rt::Condition> {
+    ) -> ftd::p1::Result<ftd::Condition> {
         let (variable, value) = match self {
             Self::Equal { left, right } => {
                 let variable = match left {
@@ -64,7 +64,6 @@ impl Boolean {
                             return ftd::e2(
                                 format!("Can't find the local variable {}", name),
                                 doc_id,
-                                doc_id.to_string(),
                                 line_number,
                             );
                         }
@@ -73,7 +72,6 @@ impl Boolean {
                         return ftd::e2(
                             format!("{:?} must be variable or local variable", left),
                             doc_id,
-                            doc_id.to_string(),
                             line_number,
                         );
                     }
@@ -93,7 +91,6 @@ impl Boolean {
                                         arg.kind()
                                     ),
                                     doc_id,
-                                    doc_id.to_string(),
                                     line_number,
                                 );
                             }
@@ -101,7 +98,6 @@ impl Boolean {
                             return ftd::e2(
                                 format!("argument not found {}", name),
                                 doc_id,
-                                doc_id.to_string(),
                                 line_number,
                             );
                         }
@@ -110,7 +106,6 @@ impl Boolean {
                         return ftd::e2(
                             format!("{:?} must be value or argument", right),
                             doc_id,
-                            doc_id.to_string(),
                             line_number,
                         );
                     }
@@ -118,14 +113,7 @@ impl Boolean {
 
                 (variable, value)
             }
-            _ => {
-                return ftd::e2(
-                    format!("{:?} must not happen", self),
-                    doc_id,
-                    doc_id.to_string(),
-                    line_number,
-                )
-            }
+            _ => return ftd::e2(format!("{:?} must not happen", self), doc_id, line_number),
         };
         match value.to_string() {
             None => {
@@ -135,11 +123,10 @@ impl Boolean {
                         value
                     ),
                     doc_id,
-                    doc_id.to_string(),
                     line_number,
                 )
             }
-            Some(value) => Ok(ftd_rt::Condition { variable, value }),
+            Some(value) => Ok(ftd::Condition { variable, value }),
         }
     }
 
@@ -173,7 +160,6 @@ impl Boolean {
                 return ftd::e2(
                     format!("'{}' is not valid condition", rest),
                     doc_id,
-                    doc_id.to_string(),
                     line_number,
                 )
             }
@@ -206,7 +192,6 @@ impl Boolean {
                     return ftd::e2(
                         format!("'{}' is not to an optional", left),
                         doc.name,
-                        doc.name.to_string(),
                         line_number,
                     );
                 }
@@ -229,7 +214,6 @@ impl Boolean {
                     return ftd::e2(
                         format!("'{}' is not to a list", left),
                         doc.name,
-                        doc.name.to_string(),
                         line_number,
                     );
                 }
@@ -282,7 +266,6 @@ impl Boolean {
                 return ftd::e2(
                     format!("'{}' is not valid condition", expr),
                     doc.name,
-                    doc.name.to_string(),
                     line_number,
                 )
             }
@@ -403,9 +386,8 @@ impl Boolean {
                 .is_equal(&right.resolve(line_number, arguments, doc)?),
             _ => {
                 return ftd::e2(
-                    "unknown Boolean found",
-                    self,
-                    doc.name.to_string(),
+                    format!("unknown Boolean found: {:?}", self),
+                    doc.name,
                     line_number,
                 )
             }
@@ -432,7 +414,6 @@ impl Boolean {
                 return ftd::e2(
                     format!("unimplemented for type: {:?}", self),
                     doc_id,
-                    doc_id.to_string(),
                     line_number,
                 )
             }
